==> jc-1.4.0.tar.gz: java/awt/dnd/DropTargetEvent.c <==
// public class java.awt.dnd.DropTargetEvent

// class file dependencies
// @dep_class 406dda8ada59c3dd java_awt_dnd_DropTargetContext
// @dep_class fb6fee3e34aaae16 java_awt_dnd_DropTargetEvent
// @dep_class 9a35c7173b37e641 java_io_Serializable
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 680cf34d05feb5a1 java_lang_IllegalArgumentException
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c8d6a6ffc5c1acc1 java_lang_VMThrowable
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_dnd_DropTargetContext
// @dep_header java_awt_dnd_DropTargetEvent
// @dep_header java_io_Serializable
// @dep_header java_lang_Class
// @dep_header java_lang_IllegalArgumentException
// @dep_header java_lang_String
// @dep_header java_lang_VMThrowable

#include "jc_defs.h"

#include "java/awt/dnd/DropTargetContext.h"
#include "java/awt/dnd/DropTargetEvent.h"
#include "java/io/Serializable.h"
#include "java/lang/Class.h"
#include "java/lang/IllegalArgumentException.h"
#include "java/lang/String.h"
#include "java/lang/VMThrowable.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// protected java.awt.dnd.DropTargetContext context
static _jc_field _jc_java_awt_dnd_DropTargetEvent$field_info$context = {
	.name=		"context",
	.signature=	"Ljava/awt/dnd/DropTargetContext;",
	.class=		&_jc_java_awt_dnd_DropTargetEvent$type,
	.type=		&_jc_java_awt_dnd_DropTargetContext$type,
	.access_flags=	_JC_ACC_PROTECTED,
	.offset=	_JC_OFFSETOF(_jc_java_awt_dnd_DropTargetEvent$object, refs[-1].java_awt_dnd_DropTargetEvent.context),
};

// Fields
static _jc_field *const _jc_java_awt_dnd_DropTargetEvent$fields[] = {
	&_jc_java_awt_dnd_DropTargetEvent$field_info$context
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.awt.dnd.DropTargetContext)
//

static _jc_linenum _jc_java_awt_dnd_DropTargetEvent$linenum_table$_init$f7d4054c820b80a8[];

static const unsigned char _jc_java_awt_dnd_DropTargetEvent$param_ptypes$_init$f7d4054c820b80a8[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_java_awt_dnd_DropTargetEvent$param_types$_init$f7d4054c820b80a8[] = {
	&_jc_java_awt_dnd_DropTargetContext$type
};

_jc_method _jc_java_awt_dnd_DropTargetEvent$method_info$_init$f7d4054c820b80a8 = {
	.name=			"<init>",
	.signature=		"(Ljava/awt/dnd/DropTargetContext;)V",
	.class=			&_jc_java_awt_dnd_DropTargetEvent$type,
	.param_types=		&_jc_java_awt_dnd_DropTargetEvent$param_types$_init$f7d4054c820b80a8,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_awt_dnd_DropTargetEvent$param_ptypes$_init$f7d4054c820b80a8,
	.signature_hash=	_JC_JLONG(0xf7d4054c820b80a8),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_awt_dnd_DropTargetEvent$method$_init$f7d4054c820b80a8,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_java_awt_dnd_DropTargetEvent$linenum_table$_init$f7d4054c820b80a8
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_awt_dnd_DropTargetEvent, _init$f7d4054c820b80a8);

void
_jc_java_awt_dnd_DropTargetEvent$method$_init$f7d4054c820b80a8(_jc_env *const env, _jc_java_awt_dnd_DropTargetEvent$object *this, _jc_java_awt_dnd_DropTargetContext$object *param0)
{
	struct _jc_java_awt_dnd_DropTargetEvent$object *r0;
	struct _jc_java_awt_dnd_DropTargetContext$object *r1;
	struct _jc_java_lang_IllegalArgumentException$object *r2;
	struct _jc_java_lang_String$object *r3;
	struct _jc_java_lang_VMThrowable$object *r5;

	r0 = this;
	r1 = param0;
	if (r1 != _JC_NULL)
		goto label0;
	r2 = _JC_NEW(env, java_lang_IllegalArgumentException);
	r3 = _JC_NULL;
	_JC_REF_FIELD(env, r2, java_lang_Throwable, cause) = r2;
	r5 = _JC_INVOKE_STATIC(env, java_lang_VMThrowable, fillInStackTrace$78894ac70fa4c0a5, 0, r2);
	_JC_REF_FIELD(env, r2, java_lang_Throwable, vmState) = r5;
	_JC_REF_FIELD(env, r2, java_lang_Throwable, stackTrace) = _JC_NULL;
	_JC_REF_FIELD(env, r2, java_lang_Throwable, detailMessage) = r3;
	_JC_THROW(env, r2);

label0:
	_JC_REF_FIELD(env, r0, java_util_EventObject, source) = r1;
	_JC_LINE_NUMBER(49);				// 0
	_JC_REF_FIELD(env, r0, java_awt_dnd_DropTargetEvent, context) = r1;
	_JC_LINE_NUMBER(50);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.awt.dnd.DropTargetContext getDropTargetContext()
//

static _jc_linenum _jc_java_awt_dnd_DropTargetEvent$linenum_table$getDropTargetContext$c80b1e104d7e50c1[];

static const unsigned char _jc_java_awt_dnd_DropTargetEvent$param_ptypes$getDropTargetContext$c80b1e104d7e50c1[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_awt_dnd_DropTargetEvent$method_info$getDropTargetContext$c80b1e104d7e50c1 = {
	.name=			"getDropTargetContext",
	.signature=		"()Ljava/awt/dnd/DropTargetContext;",
	.class=			&_jc_java_awt_dnd_DropTargetEvent$type,
	.return_type=		&_jc_java_awt_dnd_DropTargetContext$type,
	.param_ptypes=		&_jc_java_awt_dnd_DropTargetEvent$param_ptypes$getDropTargetContext$c80b1e104d7e50c1,
	.signature_hash=	_JC_JLONG(0xc80b1e104d7e50c1),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_awt_dnd_DropTargetEvent$method$getDropTargetContext$c80b1e104d7e50c1,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_awt_dnd_DropTargetEvent$vtable, java_awt_dnd_DropTargetEvent.getDropTargetContext$c80b1e104d7e50c1) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_awt_dnd_DropTargetEvent$linenum_table$getDropTargetContext$c80b1e104d7e50c1
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_awt_dnd_DropTargetEvent, getDropTargetContext$c80b1e104d7e50c1);

_jc_java_awt_dnd_DropTargetContext$object *
_jc_java_awt_dnd_DropTargetEvent$method$getDropTargetContext$c80b1e104d7e50c1(_jc_env *const env, _jc_java_awt_dnd_DropTargetEvent$object *this)
{
	struct _jc_java_awt_dnd_DropTargetEvent$object *r0;
	struct _jc_java_awt_dnd_DropTargetContext$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(54);				// 0
	r1 = _JC_REF_FIELD(env, r0, java_awt_dnd_DropTargetEvent, context);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_awt_dnd_DropTargetEvent$methods[] = {
	&_jc_java_awt_dnd_DropTargetEvent$method_info$_init$f7d4054c820b80a8,
	&_jc_java_awt_dnd_DropTargetEvent$method_info$getDropTargetContext$c80b1e104d7e50c1
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_awt_dnd_DropTargetEvent$instanceof_hash_bucket_22[] = {
	&_jc_java_awt_dnd_DropTargetEvent$type,
	_JC_NULL
};
static _jc_type *const _jc_java_awt_dnd_DropTargetEvent$instanceof_hash_bucket_43[] = {
	&_jc_java_util_EventObject$type,
	_JC_NULL
};
static _jc_type *const _jc_java_awt_dnd_DropTargetEvent$instanceof_hash_bucket_65[] = {
	&_jc_java_io_Serializable$type,
	_JC_NULL
};
static _jc_type *const _jc_java_awt_dnd_DropTargetEvent$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_awt_dnd_DropTargetEvent$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[22]=	_jc_java_awt_dnd_DropTargetEvent$instanceof_hash_bucket_22,
	[43]=	_jc_java_awt_dnd_DropTargetEvent$instanceof_hash_bucket_43,
	[65]=	_jc_java_awt_dnd_DropTargetEvent$instanceof_hash_bucket_65,
	[113]=	_jc_java_awt_dnd_DropTargetEvent$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_awt_dnd_DropTargetEvent$class_depends[] = {
	{ "java/awt/dnd/DropTargetContext",	_JC_JLONG(0x406dda8ada59c3dd) },
	{ "java/io/Serializable",	_JC_JLONG(0x9a35c7173b37e641) },
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Exception",	_JC_JLONG(0xc5feb325780a6cd7) },
	{ "java/lang/IllegalArgumentException",	_JC_JLONG(0x680cf34d05feb5a1) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/RuntimeException",	_JC_JLONG(0x4f5534a987354d1d) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/lang/Throwable",	_JC_JLONG(0x3be5c3c4fdd59a1e) },
	{ "java/lang/VMThrowable",	_JC_JLONG(0xc8d6a6ffc5c1acc1) },
	{ "java/util/EventObject",	_JC_JLONG(0xe4988e4c1a7050ab) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_awt_dnd_DropTargetEvent$vtype _jc_java_awt_dnd_DropTargetEvent$type = {
    .type= {
	.name=			"java/awt/dnd/DropTargetEvent",
	.superclass=		&_jc_java_util_EventObject$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		14,
		.hash=			_JC_JLONG(0xfb6fee3e34aaae16),
		.source_file=		"DropTargetEvent.java",
		.instance_size=		sizeof(_jc_java_awt_dnd_DropTargetEvent$refs) + sizeof(_jc_java_awt_dnd_DropTargetEvent$object),
		.num_virtual_refs=	2,
		.num_fields=		sizeof(_jc_java_awt_dnd_DropTargetEvent$fields) / sizeof(*_jc_java_awt_dnd_DropTargetEvent$fields),
		.fields=		_jc_java_awt_dnd_DropTargetEvent$fields,
		.num_methods=		sizeof(_jc_java_awt_dnd_DropTargetEvent$methods) / sizeof(*_jc_java_awt_dnd_DropTargetEvent$methods),
		.methods=		_jc_java_awt_dnd_DropTargetEvent$methods,
		.instanceof_hash_table=	_jc_java_awt_dnd_DropTargetEvent$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_awt_dnd_DropTargetEvent$class_depends) / sizeof(*_jc_java_awt_dnd_DropTargetEvent$class_depends),
		.class_depends=		_jc_java_awt_dnd_DropTargetEvent$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_java_util_EventObject$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_util_EventObject= {
	    .getSource$b11b93305f9d301e=
		&_jc_java_util_EventObject$method$getSource$b11b93305f9d301e,
	    .toString$7ea43b33b80a3070=
		&_jc_java_util_EventObject$method$toString$7ea43b33b80a3070,
	},
	.java_awt_dnd_DropTargetEvent= {
	    .getDropTargetContext$c80b1e104d7e50c1=
		&_jc_java_awt_dnd_DropTargetEvent$method$getDropTargetContext$c80b1e104d7e50c1,
	},
    }
};

==> jc-1.4.5.tar.gz: java/awt/dnd/DropTargetEvent.c <==
// public class java.awt.dnd.DropTargetEvent

// class file dependencies
// @dep_class 406dda8ada59c3dd java_awt_dnd_DropTargetContext
// @dep_class fb6fee3e34aaae16 java_awt_dnd_DropTargetEvent
// @dep_class 9a35c7173b37e641 java_io_Serializable
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 680cf34d05feb5a1 java_lang_IllegalArgumentException
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c8d6a6ffc5c1acc1 java_lang_VMThrowable
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_dnd_DropTargetContext
// @dep_header java_awt_dnd_DropTargetEvent
// @dep_header java_io_Serializable
// @dep_header java_lang_Class
// @dep_header java_lang_IllegalArgumentException
// @dep_header java_lang_String
// @dep_header java_lang_VMThrowable

#include "jc_defs.h"

#include "java/awt/dnd/DropTargetContext.h"
#include "java/awt/dnd/DropTargetEvent.h"
#include "java/io/Serializable.h"
#include "java/lang/Class.h"
#include "java/lang/IllegalArgumentException.h"
#include "java/lang/String.h"
#include "java/lang/VMThrowable.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// protected java.awt.dnd.DropTargetContext context
static _jc_field _jc_java_awt_dnd_DropTargetEvent$field_info$context = {
	.name=		"context",
	.signature=	"Ljava/awt/dnd/DropTargetContext;",
	.class=		&_jc_java_awt_dnd_DropTargetEvent$type,
	.type=		&_jc_java_awt_dnd_DropTargetContext$type,
	.access_flags=	_JC_ACC_PROTECTED,
	.offset=	_JC_OFFSETOF(_jc_java_awt_dnd_DropTargetEvent$object, refs[-1].java_awt_dnd_DropTargetEvent.context),
};

// Fields
static _jc_field *const _jc_java_awt_dnd_DropTargetEvent$fields[] = {
	&_jc_java_awt_dnd_DropTargetEvent$field_info$context
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.awt.dnd.DropTargetContext)
//

static _jc_linenum _jc_java_awt_dnd_DropTargetEvent$linenum_table$_init$f7d4054c820b80a8[];

static const unsigned char _jc_java_awt_dnd_DropTargetEvent$param_ptypes$_init$f7d4054c820b80a8[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_java_awt_dnd_DropTargetEvent$param_types$_init$f7d4054c820b80a8[] = {
	&_jc_java_awt_dnd_DropTargetContext$type
};

_jc_method _jc_java_awt_dnd_DropTargetEvent$method_info$_init$f7d4054c820b80a8 = {
	.name=			"<init>",
	.signature=		"(Ljava/awt/dnd/DropTargetContext;)V",
	.class=			&_jc_java_awt_dnd_DropTargetEvent$type,
	.param_types=		&_jc_java_awt_dnd_DropTargetEvent$param_types$_init$f7d4054c820b80a8,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_awt_dnd_DropTargetEvent$param_ptypes$_init$f7d4054c820b80a8,
	.signature_hash=	_JC_JLONG(0xf7d4054c820b80a8),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_awt_dnd_DropTargetEvent$method$_init$f7d4054c820b80a8,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_java_awt_dnd_DropTargetEvent$linenum_table$_init$f7d4054c820b80a8
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_awt_dnd_DropTargetEvent, _init$f7d4054c820b80a8);

void _JC_JCNI_ATTR
_jc_java_awt_dnd_DropTargetEvent$method$_init$f7d4054c820b80a8(_jc_env *const env, _jc_java_awt_dnd_DropTargetEvent$object *this, _jc_java_awt_dnd_DropTargetContext$object *param0)
{
	struct _jc_java_awt_dnd_DropTargetEvent$object *r0;
	struct _jc_java_awt_dnd_DropTargetContext$object *r1;
	struct _jc_java_lang_IllegalArgumentException$object *r2;
	struct _jc_java_lang_String$object *r3;
	struct _jc_java_lang_VMThrowable$object *r5;

	r0 = this;
	r1 = param0;
	if (r1 != _JC_NULL)
		goto label0;
	r2 = _JC_NEW(env, java_lang_IllegalArgumentException);
	r3 = _JC_NULL;
	_JC_REF_FIELD(env, r2, java_lang_Throwable, cause) = r2;
	r5 = _JC_INVOKE_STATIC(env, java_lang_VMThrowable, fillInStackTrace$78894ac70fa4c0a5, 0, r2);
	_JC_REF_FIELD(env, r2, java_lang_Throwable, vmState) = r5;
	_JC_REF_FIELD(env, r2, java_lang_Throwable, stackTrace) = _JC_NULL;
	_JC_REF_FIELD(env, r2, java_lang_Throwable, detailMessage) = r3;
	_JC_THROW(env, r2);

label0:
	_JC_REF_FIELD(env, r0, java_util_EventObject, source) = r1;
	_JC_LINE_NUMBER(49);				// 0
	_JC_REF_FIELD(env, r0, java_awt_dnd_DropTargetEvent, context) = r1;
	_JC_LINE_NUMBER(50);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.awt.dnd.DropTargetContext getDropTargetContext()
//

static _jc_linenum _jc_java_awt_dnd_DropTargetEvent$linenum_table$getDropTargetContext$c80b1e104d7e50c1[];

static const unsigned char _jc_java_awt_dnd_DropTargetEvent$param_ptypes$getDropTargetContext$c80b1e104d7e50c1[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_awt_dnd_DropTargetEvent$method_info$getDropTargetContext$c80b1e104d7e50c1 = {
	.name=			"getDropTargetContext",
	.signature=		"()Ljava/awt/dnd/DropTargetContext;",
	.class=			&_jc_java_awt_dnd_DropTargetEvent$type,
	.return_type=		&_jc_java_awt_dnd_DropTargetContext$type,
	.param_ptypes=		&_jc_java_awt_dnd_DropTargetEvent$param_ptypes$getDropTargetContext$c80b1e104d7e50c1,
	.signature_hash=	_JC_JLONG(0xc80b1e104d7e50c1),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_awt_dnd_DropTargetEvent$method$getDropTargetContext$c80b1e104d7e50c1,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_awt_dnd_DropTargetEvent$vtable, java_awt_dnd_DropTargetEvent.getDropTargetContext$c80b1e104d7e50c1) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_awt_dnd_DropTargetEvent$linenum_table$getDropTargetContext$c80b1e104d7e50c1
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_awt_dnd_DropTargetEvent, getDropTargetContext$c80b1e104d7e50c1);

_jc_java_awt_dnd_DropTargetContext$object * _JC_JCNI_ATTR
_jc_java_awt_dnd_DropTargetEvent$method$getDropTargetContext$c80b1e104d7e50c1(_jc_env *const env, _jc_java_awt_dnd_DropTargetEvent$object *this)
{
	struct _jc_java_awt_dnd_DropTargetEvent$object *r0;
	struct _jc_java_awt_dnd_DropTargetContext$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(54);				// 0
	r1 = _JC_REF_FIELD(env, r0, java_awt_dnd_DropTargetEvent, context);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_awt_dnd_DropTargetEvent$methods[] = {
	&_jc_java_awt_dnd_DropTargetEvent$method_info$_init$f7d4054c820b80a8,
	&_jc_java_awt_dnd_DropTargetEvent$method_info$getDropTargetContext$c80b1e104d7e50c1
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_awt_dnd_DropTargetEvent$instanceof_hash_bucket_22[] = {
	&_jc_java_awt_dnd_DropTargetEvent$type,
	_JC_NULL
};
static _jc_type *const _jc_java_awt_dnd_DropTargetEvent$instanceof_hash_bucket_43[] = {
	&_jc_java_util_EventObject$type,
	_JC_NULL
};
static _jc_type *const _jc_java_awt_dnd_DropTargetEvent$instanceof_hash_bucket_65[] = {
	&_jc_java_io_Serializable$type,
	_JC_NULL
};
static _jc_type *const _jc_java_awt_dnd_DropTargetEvent$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_awt_dnd_DropTargetEvent$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[22]=	_jc_java_awt_dnd_DropTargetEvent$instanceof_hash_bucket_22,
	[43]=	_jc_java_awt_dnd_DropTargetEvent$instanceof_hash_bucket_43,
	[65]=	_jc_java_awt_dnd_DropTargetEvent$instanceof_hash_bucket_65,
	[101]=	_jc_java_awt_dnd_DropTargetEvent$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_awt_dnd_DropTargetEvent$class_depends[] = {
	{ "java/awt/dnd/DropTargetContext",	_JC_JLONG(0x406dda8ada59c3dd) },
	{ "java/io/Serializable",	_JC_JLONG(0x9a35c7173b37e641) },
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Exception",	_JC_JLONG(0xc5feb325780a6cd7) },
	{ "java/lang/IllegalArgumentException",	_JC_JLONG(0x680cf34d05feb5a1) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/RuntimeException",	_JC_JLONG(0x4f5534a987354d1d) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/lang/Throwable",	_JC_JLONG(0x3be5c3c4fdd59a1e) },
	{ "java/lang/VMThrowable",	_JC_JLONG(0xc8d6a6ffc5c1acc1) },
	{ "java/util/EventObject",	_JC_JLONG(0xe4988e4c1a7050ab) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_awt_dnd_DropTargetEvent$vtype _jc_java_awt_dnd_DropTargetEvent$type = {
    .type= {
	.name=			"java/awt/dnd/DropTargetEvent",
	.superclass=		&_jc_java_util_EventObject$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		14,
		.hash=			_JC_JLONG(0xfb6fee3e34aaae16),
		.source_file=		"DropTargetEvent.java",
		.instance_size=		sizeof(_jc_java_awt_dnd_DropTargetEvent$refs) + sizeof(_jc_java_awt_dnd_DropTargetEvent$object),
		.num_virtual_refs=	2,
		.num_fields=		sizeof(_jc_java_awt_dnd_DropTargetEvent$fields) / sizeof(*_jc_java_awt_dnd_DropTargetEvent$fields),
		.fields=		_jc_java_awt_dnd_DropTargetEvent$fields,
		.num_methods=		sizeof(_jc_java_awt_dnd_DropTargetEvent$methods) / sizeof(*_jc_java_awt_dnd_DropTargetEvent$methods),
		.methods=		_jc_java_awt_dnd_DropTargetEvent$methods,
		.instanceof_hash_table=	_jc_java_awt_dnd_DropTargetEvent$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_awt_dnd_DropTargetEvent$class_depends) / sizeof(*_jc_java_awt_dnd_DropTargetEvent$class_depends),
		.class_depends=		_jc_java_awt_dnd_DropTargetEvent$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_java_util_EventObject$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_util_EventObject= {
	    .getSource$b11b93305f9d301e=
		&_jc_java_util_EventObject$method$getSource$b11b93305f9d301e,
	    .toString$7ea43b33b80a3070=
		&_jc_java_util_EventObject$method$toString$7ea43b33b80a3070,
	},
	.java_awt_dnd_DropTargetEvent= {
	    .getDropTargetContext$c80b1e104d7e50c1=
		&_jc_java_awt_dnd_DropTargetEvent$method$getDropTargetContext$c80b1e104d7e50c1,
	},
    }
};
